@@ -9,8 +9,16 @@ from pydantic import (
 
 
 class ApiConfig(BaseSettings):
-    BACKEND_CORS_ORIGINS: List[str] = ["*"]
-    BASE_URL: str = "/base"
+    """
+    CORS_ORIGINS    : Cors origins
+    BASE_URL    : Swagger base url
+    NAME        : Application Path
+    DESCRIPTION : Application Description
+    VERSION     : Application Version
+
+    """
+    CORS_ORIGINS: List[str] = ["*"]
+    DOC_URL: str = "/base"
     NAME: str = "LEAN API"
     DESCRIPTION: str = ""
     VERSION: str = "0.0.0"
